@@ -3,6 +3,9 @@
 
 using namespace Rcpp;
 
+extern List pwchisqCpp(const double, const Eigen::VectorXd&, const Eigen::VectorXi&,
+                       const Eigen::VectorXd&, const int, const double, const int, const double);
+
 extern List bootPICppWrap(const Eigen::VectorXd&, const Eigen::VectorXd&,
                           const Eigen::VectorXd&, const double);
 
@@ -12,7 +15,8 @@ extern void bootPICpp(const Eigen::VectorXd&, const Eigen::VectorXd&,
 
 extern NumericVector rtau2CppWrap(const int, const Eigen::VectorXd&, const Eigen::VectorXd&,
                                   const double, const int, const double,
-                                  const double, const double, const int, const double);
+                                  const double, const double, const int, const double,
+                                  const int);
 
 extern double getqa(const Eigen::VectorXd&, const Eigen::MatrixXd&);
 
@@ -30,3 +34,7 @@ extern double fx(const double, const double, const int, const double,
 
 extern void pQCpp(const double, const Eigen::VectorXd&, const int,
                   const double, const int, const double, double*, int*);
+
+extern void pQCpp2(const double, const Eigen::VectorXd&, const Eigen::VectorXi&,
+                   const Eigen::VectorXd&, const int, const double, const int,
+                   const double, double*, int*);
